@@ -14,7 +14,7 @@
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: PromptWidget.cxx 3242 2015-12-29 22:39:08Z stephena $
+// $Id: PromptWidget.cxx 3295 2016-03-07 15:36:09Z stephena $
 //============================================================================
 
 #include <iostream>
@@ -524,15 +524,9 @@ void PromptWidget::specialKeys(StellaKey key)
 
   switch(key)
   {
-    case KBDK_A:
-      _currentPos = _promptStartPos;
-      break;
     case KBDK_D:
       killChar(+1);
       break;
-    case KBDK_E:
-      _currentPos = _promptEndPos;
-      break;
     case KBDK_K:
       killLine(+1);
       break;
@@ -542,6 +536,18 @@ void PromptWidget::specialKeys(StellaKey key)
     case KBDK_W:
       killLastWord();
       break;
+    case KBDK_A:
+      textSelectAll();
+      break;
+    case KBDK_X:
+      textCut();
+      break;
+    case KBDK_C:
+      textCopy();
+      break;
+    case KBDK_V:
+      textPaste();
+      break;
     default:
       handled = false;
       break;
@@ -628,6 +634,26 @@ void PromptWidget::killLastWord()
   _promptEndPos -= cnt;
 }
 
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+void PromptWidget::textSelectAll()
+{
+}
+
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+void PromptWidget::textCut()
+{
+}
+
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+void PromptWidget::textCopy()
+{
+}
+
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+void PromptWidget::textPaste()
+{
+}
+
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void PromptWidget::addToHistory(const char* str)
 {
