@@ -14,7 +14,7 @@
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: EventHandler.cxx 3270 2016-01-31 03:42:23Z stephena $
+// $Id: EventHandler.cxx 3287 2016-02-24 20:49:49Z stephena $
 //============================================================================
 
 #include <sstream>
@@ -541,7 +541,7 @@ void EventHandler::handleKeyEvent(StellaKey key, StellaMod mod, bool state)
   // Handle keys which switch eventhandler state
   // Arrange the logic to take advantage of short-circuit evaluation
   if(!(kbdControl(mod) || kbdShift(mod) || kbdAlt(mod)) &&
-      state && eventStateChange(myKeyTable[key][kEmulationMode]))
+      !state && eventStateChange(myKeyTable[key][kEmulationMode]))
     return;
 
   // Otherwise, let the event handler deal with it
